==> robotserial-0.0.1.tar.gz: robotserial-0.0.1/setup.py <==
from io import open

from setuptools import find_packages, setup

with open('robotserial/__init__.py', 'r') as f:
    for line in f:
        if line.startswith('__version__'):
            version = line.strip().split('=')[1].strip(' \'"')
            break
    else:
        version = '0.0.1'

with open('README.rst', 'r', encoding='utf-8') as f:
    readme = f.read()

REQUIRES = []
EXTRA_REQUIRES = {
    ':python_version <= "2.7"': ['pyserial']
}

setup(
    name='robotserial',
    version=version,
    description='',
    long_description=readme,
    author='SimLeek',
    author_email='josh.miklos@gmail.com',
    maintainer='SimLeek',
    maintainer_email='josh.miklos@gmail.com',
    url='https://github.com/SimLeek/robotserial',
    license='MIT/Apache-2.0',

    keywords=[
        '',
    ],

    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
    ],

    install_requires=REQUIRES,
    extras_require=EXTRA_REQUIRES,
    tests_require=['coverage', 'pytest'],

    packages=find_packages(),
)

==> robotserial-0.0.2.tar.gz: robotserial-0.0.2/setup.py <==
from io import open

from setuptools import find_packages, setup

with open('robotserial/__init__.py', 'r') as f:
    for line in f:
        if line.startswith('__version__'):
            version = line.strip().split('=')[1].strip(' \'"')
            break
    else:
        version = '0.0.1'

with open('README.md', 'r', encoding='utf-8') as f:
    readme = f.read()

REQUIRES = []
EXTRA_REQUIRES = {
    ':python_version <= "2.7"': ['pyserial']
}

setup(
    name='robotserial',
    version=version,
    description='',
    long_description=readme,
    long_description_content_type='text/markdown',
    author='SimLeek',
    author_email='josh.miklos@gmail.com',
    maintainer='SimLeek',
    maintainer_email='josh.miklos@gmail.com',
    url='https://github.com/SimLeek/robotserial',
    license='MIT/Apache-2.0',

    keywords=[
        '',
    ],

    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
    ],

    install_requires=REQUIRES,
    extras_require=EXTRA_REQUIRES,
    tests_require=['coverage', 'pytest'],

    packages=find_packages(),
)
